@@ -26,9 +26,15 @@ dflags = {
 have_func('rb_time_timespec')
 have_func('rb_ivar_count')
 have_func('rb_ivar_foreach')
+# Support for compaction.
+have_func('rb_gc_mark_movable')
 have_func('stpcpy')
-have_func('rb_data_object_wrap')
 have_func('pthread_mutex_init')
+have_func('rb_enc_associate')
+have_func('rb_enc_interned_str')
+have_func('rb_ext_ractor_safe', 'ruby.h')
+# rb_hash_bulk_insert is deep down in a header not included in normal build and that seems to fool have_func.
+have_func('rb_hash_bulk_insert', 'ruby.h') unless '2' == version[0] && '6' == version[1]
 
 dflags['OJ_DEBUG'] = true unless ENV['OJ_DEBUG'].nil?
 
