@@ -36,8 +36,6 @@ class SharedMimicTest < Minitest::Test
     @expected_time_string =
       if defined?(Rails)
         %{"2014-05-13T16:53:20.000Z"}
-      elsif RUBY_VERSION.start_with?('1.8')
-        %{"Tue May 13 16:53:20 UTC 2014"}
       else
         %{"2014-05-13 16:53:20 UTC"}
       end
@@ -145,7 +143,7 @@ class SharedMimicTest < Minitest::Test
     Oj.mimic_JSON
     children = []
     json = %{{"a":1,"b":[true,false]}}
-    if 'rubinius' == $ruby || '1.8.7' == RUBY_VERSION
+    if 'rubinius' == $ruby
       obj = JSON.load(json) {|x| children << x }
     else
       p = Proc.new {|x| children << x }
@@ -164,6 +162,12 @@ class SharedMimicTest < Minitest::Test
     assert_raises(JSON::ParserError) { JSON.parse(json) }
   end
 
+  def test_parse_with_empty_string
+    Oj.mimic_JSON
+    assert_raises(JSON::ParserError) { JSON.parse(' ') }
+    assert_raises(JSON::ParserError) { JSON.parse("\t\t\n   ") }
+  end
+
 # []
   def test_bracket_load
     json = %{{"a":1,"b":[true,false]}}
@@ -217,18 +221,18 @@ class SharedMimicTest < Minitest::Test
   def test_pretty_generate
     json = JSON.pretty_generate({ 'a' => 1, 'b' => [true, false]})
     assert(%{{
-  "a" : 1,
-  "b" : [
+  "a": 1,
+  "b": [
     true,
     false
   ]
 }} == json ||
 %{{
-  "b" : [
+  "b": [
     true,
     false
   ],
-  "a" : 1
+  "a": 1
 }} == json)
   end
 
@@ -269,7 +273,7 @@ class SharedMimicTest < Minitest::Test
     children = []
     JSON.recurse_proc({ 'a' => 1, 'b' => [true, false]}) { |x| children << x }
     # JRuby 1.7.0 rb_yield() is broken and converts the [true, false] array into true
-    unless 'jruby' == $ruby && '1.9.3' == RUBY_VERSION
+    unless 'jruby' == $ruby
       assert([1, true, false, [true, false], { 'a' => 1, 'b' => [true, false]}] == children ||
              [true, false, [true, false], 1, { 'b' => [true, false], 'a' => 1}] == children)
     end
